@@ -1,7 +1,7 @@
 #!/usr/bin/python
 
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,15 +21,25 @@
 # it from the source dir without installing.
 
 import sys
-
+import os
 import src
-import src.configureoutput
-
-src.configureoutput.prefix = "."
-src.configureoutput.datadir = "."
-
 import src.cfg
-src.cfg.initialise(None, "default.config", "~/.solfegerc")
+
+import src.gethomedir
+if not os.path.exists(src.gethomedir.get_home_dir()):
+    os.mkdir(src.gethomedir.get_home_dir())
+
+if sys.platform == 'win32':
+    print "Using as home dir:", src.gethomedir.get_home_dir()
+
+src.cfg.initialise(None, "default.config", 
+                   os.path.join(src.gethomedir.get_home_dir(), ".solfegerc"))
+
+# i18n should be imported very early in program init because it setup
+# the _ and _i functions for the whole program.
+import src.i18n
+src.i18n.setup(".")
 
 import src.mainwin
 
+src.mainwin.start_app(".", ".")
