@@ -17,9 +17,9 @@
 
 __exercise_data__ = {
     'exercise_name': 'id-by-name',
-    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Id_entify by name")),
     'stock-icon': 'solfege-id-by-name',
-    'toolbar': 5,
+    'menupath': '/Menubar/FileMenu/MiscMenu',
+    'name': _("Id_entify by name"),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
@@ -204,9 +204,15 @@ class Gui(abstract.LessonbasedGui):
                 self.g_music_displayer.hide()
                 self.g_show.show()
             if self.m_t.m_P.header.questions_selectable:
-                if not self.get_list('ask_for_names'):
+                same_file = self.get_list("ask_for_names_fn") \
+                     == [self.get_string("lessoncollection"),
+                         self.get_string("lessonfile")]
+                if (not self.get_list('ask_for_names')) or (not same_file):
                     self.block_watch('ask_for_names')
                     self.set_list('ask_for_names', range(0, len(self.m_t.m_P.get_unique_cnames())))
+                    self.set_list("ask_for_names_fn",
+                              [self.get_string("lessoncollection"),
+                               self.get_string("lessonfile")])
                     self.unblock_watch('ask_for_names')
                 for question in self.m_t.m_P.m_questions:
                     question['active'] = 0
