@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,16 +17,16 @@
 
 __exercise_data__ = {
     'exercise_name': 'id-tone',
-    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Id_entify tone")),
     'stock-icon': 'solfege-id-tone',
-    'toolbar': 8,
+    'menupath': '/Menubar/FileMenu/MiscMenu',
+    'name': _('Id_entify tone'),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
 import inputwidgets, abstract, const, random, soundcard, gu, mpd, gnome
 import gobject
-import configureoutput
+import runtime
 import gtk
 import gu
 import statistics, statisticsviewer
@@ -108,9 +108,9 @@ class Teacher(abstract.Teacher):
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
-        if not configureoutput.WITH_GNOME:
+        if not runtime.has_gnome_canvas():
             self.practise_box.add(gtk.Label(_(
-"""This exercise don't work without GNOME.
+"""This exercise doesn't work without GNOME.
 It can pretty easy be converted to use Pixmap instead
 of GnomeCanvas, but I (tca) don't have time to do this
 right now. But I can answer questions if needed.""")))
@@ -193,7 +193,7 @@ right now. But I can answer questions if needed.""")))
         # statistics #
         ##############
         self.setup_statisticsviewer(statisticsviewer.StatisticsViewer,
-                                   _("idtone"))
+                                   _("Identify tone"))
     def new_question(self, widget=None):
         s = self.m_t.q_status
         g = self.m_t.new_question()
@@ -255,7 +255,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
     def set_percentage_label(self):
         self.g_percentage.set_text("%.1f %%" % (self.m_t.m_statistics.get()*100))
     def on_start_practise(self):
-        if not configureoutput.WITH_GNOME:
+        if not runtime.has_gnome_canvas():
             return # this exercise don't work without GnomeCanvas
         self.m_t.m_statistics.reset_session()
         self.set_percentage_label()
@@ -268,5 +268,5 @@ _("""You have to select some tones practise. Do this on the config page by setti
         self.m_t.q_status = const.QSTATUS_NO
     def on_end_practise(self):
         self.m_t.end_practise()
-        if configureoutput.WITH_GNOME:
+        if runtime.has_gnome_canvas():
             self.g_repeat.set_sensitive(False)
