@@ -21,7 +21,7 @@ import gtk, gnome.ui, gnome.canvas
 import mpd
 import soundcard
 import cfg
-import configureoutput
+import runtime
 
 class PianoKeyboard(gnome.canvas.Canvas):
     def __init__(self, lowest_tone, highest_tone, size):
@@ -557,7 +557,7 @@ class AccordionWidget(gnome.canvas.Canvas):
     def know_directions(self):
         return 1
 
-if configureoutput.WITH_GNOME:
+if runtime.has_gnome_canvas():
     inputwidget_names = [_("Buttons"), _("Piano"), _("Guitar"), _("Bass"),
                  _("5 string bass"), _("6 string bass"),
                  _("Accordion B griff"), _("Accordion C griff"),
