@@ -98,6 +98,7 @@ predef = {'dictation': 'dictation',
           'rvoice': 'rvoice',
           'satb': 'satb',
           'cmdline': 'cmdline',
+          'wavfile': 'wavfile',
           'horiz': 'horiz',
           'vertic': 'vertic',
           'yes': True,
@@ -117,6 +118,7 @@ lessonfile_functions = {
         'voice': lambda m: Music(m, 'voice'),
         'rvoice': lambda m: Music(m, 'rvoice'),
         'cmdline': lambda m: Music(m, 'cmdline'),
+        'wavfile': lambda m: Music(m, 'wavfile'),
 }
 
 class _Header:
@@ -172,6 +174,7 @@ class LessonfileCommon(object):
             question['active'] = 1
             # FIXMECOMPAT
             if isinstance(question['music'], basestring):
+                # The following line is for backward compatibility
                 question['music'] = Music(question['music'], self.header.musicformat)
             question['m_lessonfile'] = self
     def select_random_question(self):
@@ -179,6 +182,15 @@ class LessonfileCommon(object):
         Select a new question by random. It will use the music in the
         lesson file question variable 'music' when selecting transposition.
         """
+        # when we start the program with --no-random, we want to go
+        # throug all the questions in the lesson file in sequential order.
+        if cfg.get_bool('config/no_random'):
+            try:
+                self.m_no_random_idx
+            except:
+                self.m_no_random_idx = 0
+            self.header.random_transpose = False
+
         count = 0
         available_question_idx = []
         if not self.m_questions:
@@ -190,7 +202,14 @@ class LessonfileCommon(object):
             raise NoQuestionConfiguredException()
         while 1:
             count += 1
-            self._idx = random.choice(available_question_idx)
+            if cfg.get_bool('config/no_random'):
+                if self.m_no_random_idx < len(available_question_idx):
+                    self._idx = self.m_no_random_idx
+                    self.m_no_random_idx += 1
+                else:
+                    self._idx = self.m_no_random_idx = 0
+            else:
+                self._idx = random.choice(available_question_idx)
             if self.header.random_transpose:
                 if self.header.random_transpose == True:
                     self.handle_random_transpose_is_yes()
@@ -344,12 +363,14 @@ class LessonfileCommon(object):
             rel_note = m.group('note')
             nn = mpd.MusicalPitch.new_from_notename(rel_note)
             aa = m.group('pre') + nn.get_octave_notename()
-            v[i] = m.group('pre') + nn.get_notename() + v[i][len(aa)::]
+            v[i] = m.group('pre') + nn.get_notename() + v[i][len(aa):]
             return r"\staff\transpose %s\relative %s{ %s }" \
               % (self.m_transpose.get_octave_notename(), 
                  rel_note, " ".join(v))
         elif question[varname].m_musictype == 'cmdline':
             return str(question[varname])
+        elif question[varname].m_musictype == 'wavfile':
+            return question[varname].m_musicdata
         else:
             raise LessonfileException("\nUknown music type: '%s'" % question[varname].m_musictype)
     def get_music(self):
@@ -446,34 +467,38 @@ class LessonfileCommon(object):
             question = self.get_question()
         if question[varname].m_musictype == 'cmdline':
             app.run_external_program(str(question[varname].m_musicdata), cfg.get_string('lessoncollections/%s' % self.m_t.get_string('lessoncollection')), "")
+        elif question[varname].m_musictype == 'wavfile':
+            soundcard.play_wav_file(os.path.join(
+                self.m_t.get_string('lessoncollections/%s' % self.m_t.get_string('lessoncollection')),
+                question[varname].m_musicdata))
         elif question[varname].m_musictype in ('normal', 'satb', 'voice', 'rvoice'):
-            self.play_question_musicformat_normal_satb(question)
+            self.play_question_musicformat_normal_satb(question, varname)
         elif question[varname].m_musictype in 'chord':
-            self.play_question_musicformat_chord(question)
+            self.play_question_musicformat_chord(question, varname)
         else:
             raise LessonfileException("Unrecognised musictype '%s'" % question[varname].m_musictype)
-    def play_question_musicformat_normal_satb(self, question):
+    def play_question_musicformat_normal_satb(self, question, varname):
         instrument = self.prepare_instrument_list(question)
-        mpd.play_music(question.get_music(), self.get_tempo(),
+        mpd.play_music(question.get_music(varname), self.get_tempo(),
                        instrument[0], instrument[1])
-    def play_question_slowly(self, question=None):
+    def play_question_slowly(self, question=None, varname='music'):
         if not question:
             question = self.get_question()
         #assert question['music'].m_musictype == 'normal'
         #FIXME what music types should be handled differently
-        self.play_question_musicformat_normal_slowly(question)
-    def play_question_musicformat_normal_slowly(self, question):
+        self.play_question_musicformat_normal_slowly(question, varname)
+    def play_question_musicformat_normal_slowly(self, question, varname='music'):
         instrument = self.prepare_instrument_list(question)
         bpm = self.get_tempo()
         bpm = (bpm[0]/2, bpm[1])
-        mpd.play_music(question.get_music(), bpm,
+        mpd.play_music(question.get_music(varname), bpm,
                        instrument[0], instrument[1])
-    def play_question_musicformat_chord(self, question):
-        assert question['music'].m_musictype == 'chord'
+    def play_question_musicformat_chord(self, question, varname='music'):
+        assert question[varname].m_musictype == 'chord'
         instrument = self.prepare_instrument_list(question)
         assert len(instrument) in (2, 6)
         if len(instrument) == 2:
-            mpd.play_music(question.get_music(), self.get_tempo(),
+            mpd.play_music(question.get_music(varname), self.get_tempo(),
                        instrument[0], instrument[1])
         else:
             assert len(instrument) == 6
@@ -535,10 +560,9 @@ class LessonfileCommon(object):
                                     instrument[3])
             track.note(4, len(nlist)-1, mpd.notename_to_int(nlist[-1]), instrument[5])
             soundcard.synth.play_track(track)
-    def play_question_musicformat_satb_arpeggio(self):
+    def play_question_musicformat_satb_arpeggio(self, varname='music'):
         """FIXME -- for completeness, should this function should take a question argument?
         """
-        varname = 'music'
         instrument = self.prepare_instrument_list(self.get_question())
         track = soundcard.Track()
         track.set_bpm(cfg.get_int('config/default_bpm'))
@@ -560,13 +584,13 @@ class LessonfileCommon(object):
                 else:
                     track.note(4, 0, mpd.notename_to_int(n)+12, instrument[1])
         soundcard.synth.play_track(track)
-    def play_question_as_choral(self, question):
+    def play_question_as_choral(self, question, varname='music'):
         instrument = self.prepare_instrument_list(self.get_question())
         if len(instrument) == 2:
             instrument = instrument * 3
         # FIXME, only the velocity from instrument[1] is used since
         # music_to_tracklist is not complete.
-        tracklist = mpd.music_to_tracklist(question.get_music(), instrument[1])
+        tracklist = mpd.music_to_tracklist(question.get_music(varname), instrument[1])
         tracklist[0].prepend_patch(0, instrument[4])
         track = tracklist[0]
         a, b = self.get_tempo()
@@ -583,7 +607,14 @@ class LessonfileCommon(object):
         Use app default values if the variable is missing.
         Convert instrument names to integer values.
         """
-        if 'instrument' in question:
+        if self.m_t.get_bool('override_default_instrument'):
+            instrument = [self.m_t.get_int('highest_instrument'),
+                         self.m_t.get_int('highest_instrument_velocity'),
+                         self.m_t.get_int('middle_instrument'),
+                         self.m_t.get_int('middle_instrument_velocity'),
+                         self.m_t.get_int('lowest_instrument'),
+                         self.m_t.get_int('lowest_instrument_velocity')]
+        elif 'instrument' in question:
             instrument = question['instrument']
         elif 'instrument' in self.m_globals:
             instrument = self.m_globals['instrument']
