@@ -17,9 +17,9 @@
 
 __exercise_data__ = {
     'exercise_name': 'rhythm',
-    'menu_path': '%s/%s' % (_("_Rhythm"), _("Rh_ythm")),
     'stock-icon': 'solfege-rhythm',
-    'toolbar': 11,
+    'menupath': '/Menubar/FileMenu/RhythmMenu',
+    'name': _("_Rhythm"),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
@@ -73,6 +73,8 @@ class Teacher(abstract.Teacher):
                 v.append(x)
         if not v:
             return Teacher.ERR_NO_ELEMS
+        if not norest_v:
+            return Teacher.ERR_NO_ELEMS
         self.m_question = [random.choice(norest_v)]
         for x in range(1, self.get_int("num_beats")):
             self.m_question.append(random.choice(v))
@@ -312,7 +314,7 @@ class Gui(abstract.Gui):
         table.attach(gu.nSpinButton(self.m_exname, "num_beats",
                      gtk.Adjustment(4, 1, 100, 1, 10)),
                      1, 2, 0, 1, xoptions=gtk.FILL)
-        menu = gu.PercussionNameOptionMenu(self.m_exname, "rhythm_perc", "Side Stick")
+        menu = gu.PercussionNameComboBoxEntry(self.m_exname, "rhythm_perc", "Side Stick")
         table.attach(menu, 2, 3, 0, 1, xoptions=gtk.FILL)
         label = gtk.Label(_("Count in before question:"))
         label.set_alignment(1.0, 0.5)
@@ -321,7 +323,7 @@ class Gui(abstract.Gui):
         table.attach(gu.nSpinButton(self.m_exname, "count_in",
                      gtk.Adjustment(2, 0, 10, 1, 10)),
                      1, 2, 1, 2, xoptions=gtk.FILL)
-        menu = gu.PercussionNameOptionMenu(self.m_exname, "countin_perc", "Claves")
+        menu = gu.PercussionNameComboBoxEntry(self.m_exname, "countin_perc", "Claves")
         table.attach(menu, 2, 3, 1, 2, xoptions=gtk.FILL)
         #-----
         self.config_box.pack_start(gtk.HBox(), False,
